@@ -404,12 +404,20 @@ load_dist_logo (LauncherApp *app)
   g_object_unref (client);
 }
 
+static gboolean
+deactivate_shortcut (LauncherShortcut *shortcut)
+{
+  launcher_shortcut_set_active (LAUNCHER_SHORTCUT (shortcut), FALSE);
+  return FALSE;
+}
+
 static void
 on_quit_clicked (LauncherShortcut *shortcut)
 {
   gdk_spawn_command_line_on_screen (gdk_screen_get_default (),
                                     "gnome-session-save --kill --gui",
                                     NULL);
+  g_timeout_add_seconds (2, (GSourceFunc)deactivate_shortcut, shortcut);
 }
 
 static void
@@ -456,6 +464,7 @@ on_places_clicked (LauncherShortcut *shortcut, LauncherApp *app)
     app->name = g_strdup (launcher_shortcut_get_label (shortcut));
     app->pixbuf = launcher_shortcut_get_icon (shortcut);
     app->exec = g_strdup (clutter_actor_get_name (CLUTTER_ACTOR (shortcut)));
+    app->can_fav = FALSE;
 
     volume = g_object_get_data (G_OBJECT (shortcut), "volume");
     if (G_IS_VOLUME (volume))
@@ -463,7 +472,8 @@ on_places_clicked (LauncherShortcut *shortcut, LauncherApp *app)
 
     cat->applications = g_list_append (cat->applications, app);
   }
-
+  
+  launcher_catbar_deactivate (LAUNCHER_CATBAR (app->priv->catbar));
   on_new_category (NULL, cat, app);
 
   g_list_free (places);
