@@ -72,6 +72,72 @@ enum
 };
 static guint _catbar_signals[LAST_SIGNAL] = { 0 };
 
+gint  
+launcher_catbar_get_active_category (LauncherCatbar *bar)
+{
+  LauncherCatbarPrivate *priv;
+  GList *cats;
+  gint ret = 0;
+
+  g_return_val_if_fail (LAUNCHER_IS_CATBAR (bar), 0);
+  priv = bar->priv;
+
+  if (priv->active == NULL)
+    return 0;
+
+  cats = launcher_menu_get_categories (launcher_menu_get_default ());
+
+  ret = g_list_index (cats, priv->active);
+
+  return ret;
+}
+
+void  
+launcher_catbar_set_active_category (LauncherCatbar *bar,
+                                     gint            n_cat)
+{
+  LauncherCatbarPrivate *priv;
+  GList *cats;
+  LauncherShortcut *active;
+
+  g_return_if_fail (LAUNCHER_IS_CATBAR (bar));
+  priv = bar->priv;
+
+  cats = clutter_container_get_children (CLUTTER_CONTAINER (priv->grid));
+
+  active = g_list_nth_data (cats, n_cat);
+
+  if (LAUNCHER_IS_SHORTCUT (active))
+  {
+    launcher_shortcut_clicked (active);
+    launcher_shortcut_set_active (active, TRUE);
+  }
+
+  g_list_free (cats);
+}
+
+void 
+launcher_catbar_deactivate (LauncherCatbar *bar)
+{
+  LauncherCatbarPrivate *priv;
+  GList *cats, *c;
+
+  g_return_if_fail (LAUNCHER_IS_CATBAR (bar));
+  priv = bar->priv;
+
+  cats = clutter_container_get_children (CLUTTER_CONTAINER (priv->grid));
+  for (c = cats; c; c = c->next)
+  {
+    LauncherShortcut *cut = c->data;
+    
+    if (LAUNCHER_IS_SHORTCUT (cut))
+      launcher_shortcut_set_active (cut, FALSE);
+  }
+  priv->active = NULL;
+
+  g_list_free (cats);
+}
+
 static gboolean
 on_category_clicked (LauncherShortcut *hit,
                      LauncherCatbar *bar)
