@@ -29,6 +29,9 @@
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-bindings.h>
 
+#include <gconf/gconf.h>
+#include <gconf/gconf-client.h>
+
 #include "launcher-config.h"
 #include "launcher-defines.h"
 
@@ -95,6 +98,9 @@ get_cols_for_width (gint width)
 static void
 calculate_sizes (LauncherConfig *cfg)
 {
+#define LAUNCHER_DIR "/apps/ume-launcher"
+#define TABLET_MODE LAUNCHER_DIR "/tablet_mode"
+  GConfClient *client = gconf_client_get_default ();
   gint width;
   gint height;
   gint n_cols;     
@@ -118,10 +124,19 @@ calculate_sizes (LauncherConfig *cfg)
     n_cats = LANDSCAPE_CATS;
     padding = PADDING;
   }
-  
+
+  /* tablet mode checking */
+  cfg->tablet_mode = gconf_client_get_bool (client, TABLET_MODE, NULL);
+
+  if (cfg->tablet_mode && !cfg->is_portrait)
+  {
+    n_cats = LANDSCAPE_CATS - 1;
+  }
+
   cfg->win_width = width - 2* padding;
   cfg->win_height = CSH () - PANEL_HEIGHT - (2*padding);
   cfg->bar_width = cfg->win_width/n_cols;
+  cfg->n_cats = n_cats;
   
   cfg->iconview_rows = cfg->is_portrait ? 7 : get_rows_for_height (height);
   cfg->iconview_cols = get_cols_for_width (width);
@@ -137,6 +152,11 @@ calculate_sizes (LauncherConfig *cfg)
 
   if (cfg->is_portrait)
     g_debug ("Running in portrait mode");
+
+  if (cfg->tablet_mode)
+    g_debug ("Running in tablet mode");
+
+  g_object_unref (client);
 }
 
 
@@ -358,5 +378,5 @@ launcher_config_get_default (void)
 gint 
 launcher_config_get_n_cats (LauncherConfig *cfg)
 {
-  return cfg->is_portrait ? PORTRAIT_CATS : LANDSCAPE_CATS;
+  return cfg->n_cats;
 }
