@@ -104,10 +104,9 @@ on_trough_clicked (ClutterActor *scroll,
   if (!TIDY_IS_ADJUSTMENT (adjust))
     return TRUE;
 
-  diff = event->y - clutter_actor_get_y (CLUTTER_ACTOR (view)) - CAW (scroll)/2;
+  diff = event->y - clutter_actor_get_y (scroll);
 
   tidy_adjustment_get_values (adjust, NULL, &lower, &upper, NULL, NULL, NULL);
-
   diff = upper * (diff/clutter_actor_get_width (scroll));
 
   tidy_adjustment_set_value (adjust, diff);
@@ -209,17 +208,18 @@ launcher_iconview_set_category (LauncherIconview     *view,
                       G_CALLBACK (launcher_iconview_scroll_event), adjustment);
     clutter_actor_set_reactive (CLUTTER_ACTOR (scroll), TRUE);
     g_signal_connect (scroll, "scroll-event",
-                      G_CALLBACK (launcher_iconview_scroll_event), adjustment);    clutter_actor_set_opacity (frame, 100);
+                      G_CALLBACK (launcher_iconview_scroll_event), adjustment);
+    clutter_actor_set_opacity (frame, 100);
     tidy_frame_set_texture (TIDY_FRAME (scroll), frame);
 
     clutter_container_add_actor (CLUTTER_CONTAINER (view), scroll);
-    clutter_actor_set_size (scroll, view_height*0.97, 10);
+    clutter_actor_set_size (scroll, view_height * 0.97, 
+                            cfg->tablet_mode ? 16 : 10);
     clutter_actor_set_anchor_point_from_gravity (scroll, 
                                                  CLUTTER_GRAVITY_CENTER);
     clutter_actor_set_position (scroll, 
-                                view_width- 10/2,
+                                view_width - (cfg->tablet_mode ? 10 : 5),
                                 view_height/2);
-  
     clutter_actor_set_rotation (scroll, CLUTTER_Z_AXIS, 90, 0, 0, 0);
     clutter_actor_show (scroll);
 
@@ -231,7 +231,6 @@ launcher_iconview_set_category (LauncherIconview     *view,
     g_signal_connect (priv->scroll, "button-press-event", 
                       G_CALLBACK (on_trough_clicked), view);
   }
-
 }
 
 
