@@ -251,6 +251,71 @@ ensure_layout (LauncherSidebar *bar)
 /*
  * PLACES 
  */
+static void
+on_places_mount (GFile *file, GAsyncResult *res, LauncherShortcut *shortcut)
+{
+  GdkPixbuf *temp;
+  GError *error = NULL;
+  gboolean success;
+  
+  success = g_file_mount_enclosing_volume_finish (file, res, &error);
+
+  if (success)
+  {
+    g_app_info_launch_default_for_uri (g_file_get_uri (file), NULL, &error);
+  }
+
+  temp = launcher_shortcut_get_icon (LAUNCHER_SHORTCUT (shortcut));
+  launcher_notify_popup (launcher_notify_get_default (),
+                  launcher_shortcut_get_label (LAUNCHER_SHORTCUT (shortcut)),
+                         temp, 
+                         -1);
+
+  g_object_unref (temp);
+  g_object_unref (file);
+}
+
+static void
+on_place_clicked (ClutterActor *shortcut, gpointer null)
+{
+  GVfs *vfs;
+  GFile *file;
+  const gchar *uri;
+  GdkPixbuf *temp;
+  GError *error = NULL;
+
+  launcher_shortcut_set_active (LAUNCHER_SHORTCUT (shortcut), FALSE);
+
+  uri = clutter_actor_get_name (shortcut);
+
+  if (!uri)
+    return;
+
+  g_app_info_launch_default_for_uri (uri, NULL, &error);
+
+  if (error)
+  {
+    g_warning ("%s\n", error->message);
+    g_error_free (error);
+
+    vfs = g_vfs_get_default ();
+    file = g_vfs_get_file_for_uri (vfs, uri);
+    g_file_mount_enclosing_volume (file, 0, NULL, NULL, 
+                                   (GAsyncReadyCallback)on_places_mount,
+                                   shortcut);
+
+    return;
+  }
+
+  temp = launcher_shortcut_get_icon (LAUNCHER_SHORTCUT (shortcut));
+  launcher_notify_popup (launcher_notify_get_default (),
+                  launcher_shortcut_get_label (LAUNCHER_SHORTCUT (shortcut)),
+                         temp, 
+                         -1);
+
+  g_object_unref (temp);
+}
+
 static ClutterActor * 
 add_place (LauncherSidebar *sidebar, 
            const gchar *icon_name, 
@@ -259,18 +324,68 @@ add_place (LauncherSidebar *sidebar,
 {
   LauncherSidebarPrivate *priv = sidebar->priv;
   ClutterActor *shortcut;
-   
+  
+  //g_print ("%s: %s\n", command, icon_name);
   shortcut = launcher_shortcut_new (icon_name, name, FALSE);
   clutter_container_add_actor (CLUTTER_CONTAINER (priv->grid), shortcut);
   clutter_actor_set_name (shortcut, command);
   clutter_actor_show_all(shortcut);
 
   priv->places = g_list_append (priv->places, shortcut);
-  g_signal_connect (shortcut, "clicked", G_CALLBACK (on_link_clicked), NULL);
+  g_signal_connect (shortcut, "clicked", G_CALLBACK (on_place_clicked), NULL);
   
   return shortcut;
 }
 
+static gchar *
+get_icon_name_for_place (const gchar *uri)
+{
+  GFile *file;
+  GFileInfo *info;
+  GIcon *icon = NULL;
+  const gchar * const *names;
+  GtkIconTheme *icon_theme;
+  int i;
+
+  file = g_file_new_for_uri (uri);
+  info = g_file_query_info (file, G_FILE_ATTRIBUTE_STANDARD_ICON, 
+                            0, NULL, NULL);
+  if (info)
+    icon = (GIcon*)g_file_info_get_attribute_object (info, 
+                                             G_FILE_ATTRIBUTE_STANDARD_ICON);
+
+  if (!G_IS_THEMED_ICON (icon))
+  {
+    g_object_unref (file);
+    if (info)
+      g_object_unref (info);
+
+    g_print ("Not themed icon: %s\n", uri);
+
+    return g_strdup ("folder");
+  }
+
+  names = g_themed_icon_get_names (G_THEMED_ICON (icon));
+  icon_theme = gtk_icon_theme_get_default ();
+
+  for (i = 0; names[i] != NULL; i++)
+  {
+    if (gtk_icon_theme_has_icon (icon_theme, names[i]))
+    {
+      gchar *ret = g_strdup (names[i]);
+      
+      g_object_unref (file);
+      g_object_unref (info);
+      
+      return ret;
+    }
+  }
+
+  g_object_unref (file);
+  g_object_unref (info);
+
+  return NULL;
+}
 static void
 load_places (LauncherSidebar *bar)
 {
@@ -307,7 +422,7 @@ load_places (LauncherSidebar *bar)
 
     for (i = 0; bookmarks[i]; i++)
     {
-      const gchar *icon_name = "folder";
+      gchar *icon_name;
       gchar *label;
 
       label = strchr (bookmarks[i], ' ');
@@ -326,14 +441,13 @@ load_places (LauncherSidebar *bar)
            && !g_ascii_strcasecmp (bookmarks[i], "network:///"))
       {
         label = _("Network");
-        icon_name = "gnome-fs-network";
       }
       
       if (label)
       {
-        path = g_strdup_printf (NAUTILUS, bookmarks[i]);
-        add_place (bar, icon_name, label, path);
-        g_free (path);
+        icon_name = get_icon_name_for_place (bookmarks[i]);
+        add_place (bar, icon_name, label, bookmarks[i]);
+        g_free (icon_name);
       }
     }
     g_strfreev (bookmarks);
